pub fn lookup_library_by_name(name: &str) -> Result<Descriptor, TwzError>Expand description
Look up a library by name in the caller’s compartment. Returns a library handle descriptor.
pub fn lookup_library_by_name(name: &str) -> Result<Descriptor, TwzError>Look up a library by name in the caller’s compartment. Returns a library handle descriptor.