Struct NewCompartmentFlags
pub struct NewCompartmentFlags(/* private fields */);Implementations
impl NewCompartmentFlags
impl NewCompartmentFlags
pub const EXPORT_GATES: NewCompartmentFlags
pub const DEBUG: NewCompartmentFlags
impl NewCompartmentFlags
impl NewCompartmentFlags
pub const fn empty() -> NewCompartmentFlags
pub const fn empty() -> NewCompartmentFlags
Get a flags value with all bits unset.
pub const fn all() -> NewCompartmentFlags
pub const fn all() -> NewCompartmentFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<NewCompartmentFlags>
pub const fn from_bits(bits: u32) -> Option<NewCompartmentFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> NewCompartmentFlags
pub const fn from_bits_truncate(bits: u32) -> NewCompartmentFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> NewCompartmentFlags
pub const fn from_bits_retain(bits: u32) -> NewCompartmentFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<NewCompartmentFlags>
pub fn from_name(name: &str) -> Option<NewCompartmentFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: NewCompartmentFlags) -> bool
pub const fn intersects(&self, other: NewCompartmentFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
pub const fn contains(&self, other: NewCompartmentFlags) -> bool
pub const fn contains(&self, other: NewCompartmentFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
pub fn insert(&mut self, other: NewCompartmentFlags)
pub fn insert(&mut self, other: NewCompartmentFlags)
The bitwise or (|) of the bits in two flags values.
pub fn remove(&mut self, other: NewCompartmentFlags)
pub fn remove(&mut self, other: NewCompartmentFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: NewCompartmentFlags)
pub fn toggle(&mut self, other: NewCompartmentFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
pub fn set(&mut self, other: NewCompartmentFlags, value: bool)
pub fn set(&mut self, other: NewCompartmentFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: NewCompartmentFlags,
) -> NewCompartmentFlags
pub const fn intersection( self, other: NewCompartmentFlags, ) -> NewCompartmentFlags
The bitwise and (&) of the bits in two flags values.
pub const fn union(self, other: NewCompartmentFlags) -> NewCompartmentFlags
pub const fn union(self, other: NewCompartmentFlags) -> NewCompartmentFlags
The bitwise or (|) of the bits in two flags values.
pub const fn difference(self, other: NewCompartmentFlags) -> NewCompartmentFlags
pub const fn difference(self, other: NewCompartmentFlags) -> NewCompartmentFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: NewCompartmentFlags,
) -> NewCompartmentFlags
pub const fn symmetric_difference( self, other: NewCompartmentFlags, ) -> NewCompartmentFlags
The bitwise exclusive-or (^) of the bits in two flags values.
pub const fn complement(self) -> NewCompartmentFlags
pub const fn complement(self) -> NewCompartmentFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
impl NewCompartmentFlags
impl NewCompartmentFlags
pub const fn iter(&self) -> Iter<NewCompartmentFlags>
pub const fn iter(&self) -> Iter<NewCompartmentFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<NewCompartmentFlags>
pub const fn iter_names(&self) -> IterNames<NewCompartmentFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.